@@ -2,10 +2,12 @@ package Rose::DB::Object::Metadata::Column::Varchar;
 
 use strict;
 
+use Carp();
+
 use Rose::DB::Object::Metadata::Column::Character;
 our @ISA = qw(Rose::DB::Object::Metadata::Column::Character);
 
-our $VERSION = '0.03';
+our $VERSION = '0.802';
 
 foreach my $type (__PACKAGE__->available_method_types)
 {
@@ -16,8 +18,31 @@ sub type { 'varchar' }
 
 sub parse_value
 {
-  my $length = $_[0]->length or return $_[2];
-  return substr($_[2], 0, $length);
+  my ($self, $db, $value) = @_;
+
+  my $length = $self->length or return $value;
+
+  if(length($value) > $length)
+  {
+    my $overflow = $self->overflow;
+      
+    if($overflow eq 'fatal')
+    {
+      local $Carp::CarpLevel = $Carp::CarpLevel + 1;
+      Carp::croak 'Value for ', $self->name, ' is too long.  Maximum ',
+                  "length is $length character@{[ $length == 1 ? '' : 's' ]}.  ",
+                  "Value is ", length(\$value), " characters: $value";
+    }
+    elsif($overflow eq 'warn')
+    {
+      local $Carp::CarpLevel = $Carp::CarpLevel + 1;
+      Carp::carp 'Value for ', $self->name, ' is too long.  Maximum ',
+                 "length is $length character@{[ $length == 1 ? '' : 's' ]}.  ",
+                 "Value is ", length(\$value), " characters: $value";
+    }
+  }
+
+  return substr($value, 0, $length);
 }
 
 *format_value = \&parse_value;
